@@ -15,11 +15,11 @@
  *                MdcApplyReadOptions()   - Apply read options             *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id$
+/*
  */
 
 /*
-   Copyright (C) 1997-2018 by Erik Nolf
+   Copyright (C) 1997-2021 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -329,7 +329,7 @@ void MdcPrintShortInfo(void)
   }
     MdcPrntScrn(" Medical Image Conversion Utility\n");
     MdcPrntScrn("(X)MedCon %s\n",MdcGetLibShortVersion());
-    MdcPrntScrn("Copyright (C) 1997-2018 by Erik Nolf\n\n");
+    MdcPrntScrn("Copyright (C) 1997-2021 by Erik Nolf\n\n");
 
   if (XMDC_GUI == MDC_YES) {
     MdcPrntScrn("Try \'xmedcon --help\' for more information.\n\n");
@@ -858,12 +858,12 @@ int MdcHandleArgs(FILEINFO *fi, int argc, char *argv[], int MAXFILES)
          if (MDC_FILE_STDIN == MDC_NO) {
            /* input from files */
 
-           if ( total[MDC_FILES] == MAXFILES)
+           if ( total[MDC_FILES] == MAXFILES ) {
              MdcPrntErr(MDC_OVER_FLOW,"Too many files specified (max=%d)"
                                      ,MAXFILES);
-           else
+           }else{
              files[total[MDC_FILES]]=argv[a]; total[MDC_FILES]+=1;
-
+           }
          }else{
            /* input from stdin */
 
